@@ -4,7 +4,6 @@ import sys
 import re
 import time
 import shlex
-import string
 import importlib
 import random
 import subprocess
@@ -217,8 +216,6 @@ def scan_var(variable):
     access = access_spec = None
     for item, name in ((key, "key"), (index, "index")):
         if item is not None:
-            if name == "index":
-                item = int(item)
             access = name
             access_spec = item
     info = {"namespace": namespace, "var": base,
@@ -226,6 +223,28 @@ def scan_var(variable):
     return info
 
 
+def do_var_access(variable, access, spec):
+    if access == "index":
+        if ":" not in spec:
+            return variable[int(spec)]
+        cache = spec.split(":")
+        if len(cache) > 2:
+            msg = "There is more than 1 colon ':' in the index spec."
+            raise error.Error(msg)
+        left, right = cache
+        left = left if left else 0
+        left = left if left else 0
+        if not right:
+            return variable[int(left):]
+        right = int(right)
+        return variable[int(left):int(right)]
+    elif access == "key":
+        return variable[spec]
+    else:
+        msg = "Unknown variable access ''."
+        raise error.Error(msg.format(access))
+
+
 def match_resource(path, regex=None, field=None, preposition=None,
                    timestamp1=None, timestamp2=None):
     false_results = 0
@@ -582,7 +601,7 @@ def get_content_iterator(runner, element, variable, tag):
 
 def iterate_content(content, spec):
     if isinstance(content, pathlib.Path):
-        filename = content.resolve()
+        filename = str(content.resolve())
         for x in _iterate_file(filename, spec):
             yield x
     elif spec == "char":
